@@ -56,9 +56,9 @@ otherwise.
 ### XXX remove this list and move it into selfupdate, somehow..
 ### this is dual administration
 {   my $query_list = {
-        'File::Fetch'   => '0.13_02',
-        'YAML::Tiny'    => '0.0',
-        'File::Temp'    => '0.0',
+        'File::Fetch'          => '0.13_02',
+        'Parse::CPAN::Meta'    => '0.0',
+        'File::Temp'           => '0.0',
     };
 
     my $send_list = {
@@ -103,36 +103,44 @@ otherwise.
 
 This function queries the CPAN testers database at
 I<http://testers.cpan.org/> for test results of specified module objects,
-module names or distributions.
+module names or distributions. 
 
 The optional argument C<all_versions> controls whether all versions of
 a given distribution should be grabbed.  It defaults to false
 (fetching only reports for the current version).
 
 Returns the a list with the following data structures (for CPANPLUS
-version 0.042) on success, or false on failure:
+version 0.042) on success, or false on failure. The contents of the
+data structure depends on what I<http://testers.cpan.org> returns,
+but generally looks like this:
 
           {
             'grade' => 'PASS',
             'dist' => 'CPANPLUS-0.042',
             'platform' => 'i686-pld-linux-thread-multi'
+            'details' => 'http://nntp.x.perl.org/group/perl.cpan.testers/98316'
+            ...
           },
           {
             'grade' => 'PASS',
             'dist' => 'CPANPLUS-0.042',
             'platform' => 'i686-linux-thread-multi'
+            'details' => 'http://nntp.x.perl.org/group/perl.cpan.testers/99416'
+            ...
           },
           {
             'grade' => 'FAIL',
             'dist' => 'CPANPLUS-0.042',
             'platform' => 'cygwin-multi-64int',
             'details' => 'http://nntp.x.perl.org/group/perl.cpan.testers/99371'
+            ...
           },
           {
             'grade' => 'FAIL',
             'dist' => 'CPANPLUS-0.042',
             'platform' => 'i586-linux',
             'details' => 'http://nntp.x.perl.org/group/perl.cpan.testers/99396'
+            ...
           },
 
 The status of the test can be one of the following:
@@ -188,27 +196,28 @@ sub _query_report {
         do { local $/; <$fh> };
     };
 
-    my ($aref) = eval { YAML::Tiny::Load( $res ) };
+    my ($aref) = eval { Parse::CPAN::Meta::Load( $res ) };
 
     if( $@ ) {
         error(loc("Error reading result: %1", $@));
         return;
     };
 
-    my $dist = $mod->package_name .'-'. $mod->package_version;
+    my $dist    = $mod->package_name .'-'. $mod->package_version;
+    my $details = TESTERS_DETAILS_URL->($mod->package_name);
 
     my @rv;
     for my $href ( @$aref ) {
         next unless $all or defined $href->{'distversion'} && 
                             $href->{'distversion'} eq $dist;
 
-        push @rv, { platform    => $href->{'platform'},
-                    grade       => $href->{'action'},
-                    dist        => $href->{'distversion'},
-                    ( $href->{'action'} eq 'FAIL'
-                        ? (details => TESTERS_DETAILS_URL->($mod->package_name))
-                        : ()
-                    ) };
+        $href->{'details'}  = $details;
+        
+        ### backwards compatibility :(
+        $href->{'dist'}     ||= $href->{'distversion'};
+        $href->{'grade'}    ||= $href->{'action'} || $href->{'status'};
+
+        push @rv, $href;
     }
 
     return @rv if @rv;
@@ -349,7 +358,7 @@ sub _send_report {
                 ### version of perl (5.8.6+ and 5.9.2-4 at the time of writing)
                 ### 'Config' is not recognized as a core module. See this bug:
                 ###    http://rt.cpan.org/Ticket/Display.html?id=32155
-                if( not $obj and not $sub->( $prq_name ) ) {
+                if( !$obj and !$sub->( $prq_name ) ) {
                     msg(loc( "Prerequisite '%1' for '%2' could not be obtained".
                              " from CPAN -- sending N/A grade", 
                              $prq_name, $name ), $verbose );
